@@ -44,7 +44,7 @@ if not configurationhandler.project_config:
 project_name = configurationhandler.project_config['project']
 python_name = templatetools.python_name(project_name)
 project_sentence_name, project_camel_case_name = \
-    quicklyutils.conventional_names(project_name)
+    templatetools.conventional_names(project_name)
 
 substitutions = (("project_name",project_name),
                  ("project_camel_case_name",project_camel_case_name),
@@ -150,7 +150,7 @@ if project_version < '0.4':
     if not os.path.isfile('%s/helpers.py' % python_name) and os.path.isdir(python_name):
         source_dir = os.path.join(os.path.dirname(__file__), 'project_root',
                                   'python')
-        quicklyutils.file_from_template(source_dir, 
+        templatetools.file_from_template(source_dir, 
                                         "helpers.py", 
                                         python_name, 
                                         substitutions)
@@ -188,13 +188,26 @@ if (os.path.exists(os.path.join(PROJECT_ROOT_DIRECTORY, '%(python_name)s'))
 if python_path:
     os.putenv('PYTHONPATH', "%%s:%%s" %% (os.getenv('PYTHONPATH', ''), ':'.join(python_path))) # for subprocesses''' % {'python_name' : python_name, 'project_name' : project_name}
 
-    try:
-        templatetools.update_file_content("./bin/%s" % project_name,
-                'if (os.path.exists(os.path.join(PROJECT_ROOT_DIRECTORY',
-                "    os.putenv('PYTHONPATH', PROJECT_ROOT_DIRECTORY) # for subprocesses",
-                content_to_update)
-    except templatetools.CantUpdateFile, e:
-        print _("WARNING: can't update your project to support /opt. This doesn't matter if you don't plan to submit your project to the application review board. Cause is: %s" % e)
+    # projects based on ~/quickly-projects/template-name have no project_version
+    # so only upgrade if really necessary     
+    with open("./bin/%s" % project_name) as project_bin:
+        contents =  project_bin.read()
+    if not content_to_update in contents:
+        try:
+            templatetools.update_file_content("./bin/%s" % project_name,
+                    'if (os.path.exists(os.path.join(PROJECT_ROOT_DIRECTORY',
+                    "    os.putenv('PYTHONPATH', PROJECT_ROOT_DIRECTORY) # for subprocesses",
+                    content_to_update)
+        except templatetools.CantUpdateFile, e:
+            print _("WARNING: can't update your project to support /opt. This doesn't matter if you don't plan to submit your project to the application review board. Cause is: %s" % e)
 
+### 11.09 update
+if project_version < '11.09':
+    filename = './%s_lib/Builder.py' % python_name
+    with open(filename) as fileobj:
+        contents = fileobj.read()
+    contents = contents.replace('from gi.repository import GObject', 'import gobject')
+    contents = contents.replace('GObject.', 'gobject.')
+    templatetools.set_file_contents(filename, contents)
 
 sys.exit(0)
